# {py:mod}`flashscenic`

```{py:module} flashscenic
```

```{autodoc2-docstring} flashscenic
:allowtitles:
```

## Submodules

```{toctree}
:titlesonly:
:maxdepth: 1

flashscenic.data
flashscenic.aucell
flashscenic.cistarget
flashscenic.pipeline
flashscenic.modules
```

## Package Contents

### Functions

````{list-table}
:class: autosummary longtable
:align: left

* - {py:obj}`regulons_to_adjacency <flashscenic.regulons_to_adjacency>`
  - ```{autodoc2-docstring} flashscenic.regulons_to_adjacency
    :summary:
    ```
````

### Data

````{list-table}
:class: autosummary longtable
:align: left

* - {py:obj}`__all__ <flashscenic.__all__>`
  - ```{autodoc2-docstring} flashscenic.__all__
    :summary:
    ```
````

### API

````{py:function} regulons_to_adjacency(regulons: list[dict], gene_names: list[str]) -> numpy.ndarray
:canonical: flashscenic.regulons_to_adjacency

```{autodoc2-docstring} flashscenic.regulons_to_adjacency
```
````

````{py:data} __all__
:canonical: flashscenic.__all__
:value: >
   ['run_flashscenic', 'download_data', 'DownloadedResources', 'list_available_resources', 'get_aucell'...

```{autodoc2-docstring} flashscenic.__all__
```

````
